@@ -6,11 +6,11 @@ import socket
 from dataclasses import dataclass
 from datetime import date, datetime, timedelta, timezone
 from importlib import metadata
-from typing import Any
+from typing import Any, cast
 
-import aiohttp
 import async_timeout
-from aiohttp import hdrs
+from aiohttp.client import ClientError, ClientSession
+from aiohttp.hdrs import METH_GET
 from yarl import URL
 
 from .exceptions import (
@@ -27,7 +27,7 @@ class EasyEnergy:
 
     incl_vat: str = "true"
     request_timeout: float = 10.0
-    session: aiohttp.client.ClientSession | None = None
+    session: ClientSession | None = None
 
     _close_session: bool = False
 
@@ -35,20 +35,23 @@ class EasyEnergy:
         self,
         uri: str,
         *,
-        method: str = hdrs.METH_GET,
+        method: str = METH_GET,
         params: dict[str, Any] | None = None,
     ) -> Any:
         """Handle a request to the API of easyEnergy.
 
-        Args:
+        Args
+        ----
             uri: Request URI, without '/', for example, 'status'
             method: HTTP method to use, for example, 'GET'
             params: Extra options to improve or limit the response.
 
-        Returns:
+        Returns
+        -------
             A Python dictionary (json) with the response from easyEnergy.
 
-        Raises:
+        Raises
+        ------
             EasyEnergyConnectionError: An error occurred while
                 communicating with the API.
             EasyEnergyError: Received an unexpected response from
@@ -56,7 +59,9 @@ class EasyEnergy:
         """
         version = metadata.version(__package__)
         url = URL.build(
-            scheme="https", host="mijn.easyenergy.com", path="/nl/api/tariff/"
+            scheme="https",
+            host="mijn.easyenergy.com",
+            path="/nl/api/tariff/",
         ).join(URL(uri))
 
         headers = {
@@ -65,7 +70,7 @@ class EasyEnergy:
         }
 
         if self.session is None:
-            self.session = aiohttp.ClientSession()
+            self.session = ClientSession()
             self._close_session = True
 
         try:
@@ -79,35 +84,41 @@ class EasyEnergy:
                 )
                 response.raise_for_status()
         except asyncio.TimeoutError as exception:
+            msg = "Timeout occurred while connecting to the API."
             raise EasyEnergyConnectionError(
-                "Timeout occurred while connecting to the API."
+                msg,
             ) from exception
-        except (aiohttp.ClientError, socket.gaierror) as exception:
+        except (ClientError, socket.gaierror) as exception:
+            msg = "Error occurred while communicating with the API."
             raise EasyEnergyConnectionError(
-                "Error occurred while communicating with the API."
+                msg,
             ) from exception
 
         content_type = response.headers.get("Content-Type", "")
         if "application/json" not in content_type:
             text = await response.text()
+            msg = "Unexpected content type response from the easyEnergy API"
             raise EasyEnergyError(
-                "Unexpected content type response from the easyEnergy API",
+                msg,
                 {"Content-Type": content_type, "response": text},
             )
 
-        return await response.json()
+        return cast(dict[str, Any], await response.json())
 
     async def gas_prices(self, start_date: date, end_date: date) -> Gas:
         """Get gas prices for a given period.
 
-        Args:
+        Args
+        ----
             start_date: Start date of the period.
             end_date: End date of the period.
 
-        Returns:
+        Returns
+        -------
             A Python dictionary with the response from easyEnergy.
 
-        Raises:
+        Raises
+        ------
             EasyEnergyNoDataError: No gas prices found for this period.
         """
         start_date_utc: datetime
@@ -116,18 +127,42 @@ class EasyEnergy:
         if utcnow.hour >= 5 and utcnow.hour <= 22:
             # Set start_date to 05:00:00 and the end_date to 05:00:00 UTC next day
             start_date_utc = datetime(
-                start_date.year, start_date.month, start_date.day, 5, 0, 0
+                start_date.year,
+                start_date.month,
+                start_date.day,
+                5,
+                0,
+                0,
+                tzinfo=timezone.utc,
             )
             end_date_utc = datetime(
-                end_date.year, end_date.month, end_date.day, 5, 0, 0
+                end_date.year,
+                end_date.month,
+                end_date.day,
+                5,
+                0,
+                0,
+                tzinfo=timezone.utc,
             ) + timedelta(days=1)
         else:
             # Set start_date to 05:00:00 prev day and the end_date to 05:00:00 UTC
             start_date_utc = datetime(
-                start_date.year, start_date.month, start_date.day, 5, 0, 0
+                start_date.year,
+                start_date.month,
+                start_date.day,
+                5,
+                0,
+                0,
+                tzinfo=timezone.utc,
             ) - timedelta(days=1)
             end_date_utc = datetime(
-                end_date.year, end_date.month, end_date.day, 5, 0, 0
+                end_date.year,
+                end_date.month,
+                end_date.day,
+                5,
+                0,
+                0,
+                tzinfo=timezone.utc,
             )
 
         data = await self._request(
@@ -140,28 +175,44 @@ class EasyEnergy:
         )
 
         if len(data) == 0:
-            raise EasyEnergyNoDataError("No gas prices found for this period.")
+            msg = "No gas prices found for this period."
+            raise EasyEnergyNoDataError(msg)
         return Gas.from_dict(data)
 
     async def energy_prices(self, start_date: date, end_date: date) -> Electricity:
         """Get energy prices for a given period.
 
-        Args:
+        Args
+        ----
             start_date: Start date of the period.
             end_date: End date of the period.
 
-        Returns:
+        Returns
+        -------
             A Python dictionary with the response from easyEnergy.
 
-        Raises:
+        Raises
+        ------
             EasyEnergyNoDataError: No energy prices found for this period.
         """
         # Set the start date to 23:00:00 previous day and the end date to 23:00:00 UTC
         start_date_utc: datetime = datetime(
-            start_date.year, start_date.month, start_date.day, 0, 0, 0
+            start_date.year,
+            start_date.month,
+            start_date.day,
+            0,
+            0,
+            0,
+            tzinfo=timezone.utc,
         ) - timedelta(hours=1)
         end_date_utc: datetime = datetime(
-            end_date.year, end_date.month, end_date.day, 23, 0, 0
+            end_date.year,
+            end_date.month,
+            end_date.day,
+            23,
+            0,
+            0,
+            tzinfo=timezone.utc,
         )
         data = await self._request(
             "getapxtariffs",
@@ -173,7 +224,8 @@ class EasyEnergy:
         )
 
         if len(data) == 0:
-            raise EasyEnergyNoDataError("No energy prices found for this period.")
+            msg = "No energy prices found for this period."
+            raise EasyEnergyNoDataError(msg)
         return Electricity.from_dict(data)
 
     async def close(self) -> None:
@@ -184,7 +236,8 @@ class EasyEnergy:
     async def __aenter__(self) -> EasyEnergy:
         """Async enter.
 
-        Returns:
+        Returns
+        -------
             The EasyEnergy object.
         """
         return self
@@ -193,6 +246,7 @@ class EasyEnergy:
         """Async exit.
 
         Args:
+        ----
             _exc_info: Exec type.
         """
         await self.close()
